@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.3305
+Version 2.34
 
 =head1 SYNOPSIS
 
@@ -53,12 +53,19 @@ If the dictionary file contains following data:
 above command finds the first pattern which does not match the second
 string, that is "colour" and "centre" in this case.
 
-Field C<//> in dictionary data is ignored, so this file can be written
-like this:
+In practice, the last two elements of a space-separated string are
+treated as a pattern and a replacement string, respectively.
+
+Dictionary data can also be written separated by C<//> as follows:
 
     colou?r      //  color
     cent(er|re)  //  center
 
+There must be spaces before and after the C<//>.  In this format,
+strings before and after it are treated as a pattern and replacement
+string, rather than last two element.  Leading spaces and spaces
+before and after C<//> are ignored, but all other whitespace is valid.
+
 You can use same file by B<greple>'s B<-f> option and string after
 C<//> is ignored as a comment in that case.
 
@@ -360,7 +367,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright 2017-2023 Kazumasa Utashiro.
+Copyright 2017-2024 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -371,7 +378,7 @@ it under the same terms as Perl itself.
 use v5.14;
 package App::Greple::subst;
 
-our $VERSION = '2.3305';
+our $VERSION = '2.34';
 
 use warnings;
 use utf8;
@@ -415,7 +422,7 @@ our @opt_format;
 our @default_opt_format = ( '%s' );
 our $opt_subst_select;
 our $opt_linefold;
-our $opt_ignore_space = 1;
+our $opt_ignore_space = 0;
 our $opt_warn_overlap = 1;
 our $opt_warn_include = 0;
 our $opt_stat_style = "default";
@@ -426,6 +433,8 @@ our %opt_stat_item = (
     );
 our $opt_show_comment = 0;
 our $opt_show_numbers = 1;
+our $opt_show_dictdir = 0;
+
 my %stat;
 
 my $current_file;
@@ -440,6 +449,11 @@ sub subst_initialize {
 
     state $once_called++ and return;
 
+    if ($opt_show_dictdir) {
+	say "$ENV{GREPLE_SUBST_DICT}";
+	exit;
+    }
+
     Getopt::EX::LabeledParam
 	->new(HASH => \%opt_stat_item)
 	->load_params(@opt_stat_item);
@@ -690,6 +704,7 @@ builtin warn-overlap!  $opt_warn_overlap
 builtin warn-include!  $opt_warn_include
 builtin ignore-space!  $opt_ignore_space
 builtin show-comment!  $opt_show_comment
+builtin    exdictdir!  $opt_show_dictdir
 
 # override greple's original option
 option --select --subst-select
@@ -734,8 +749,6 @@ option	--subst-color-dark --colormap --dyncmap \
 
 option --exdict  --dict $ENV{GREPLE_SUBST_DICT}/$<shift>
 
-option --exdictdir --prologue 'sub{ say "$ENV{GREPLE_SUBST_DICT}"; exit }'
-
 option --jtca-katakana-guide --exdict jtca-katakana-guide-3.dict
 option --jtf-style-guide     --exdict jtf-style-guide-3.dict
 option --ms-style-guide      --exdict ms-style-guide.dict
@@ -744,6 +757,7 @@ option --sccc2     --exdict sccc2.dict
 option --jtca      --exdict jtca.dict
 option --jtf       --exdict jtf.dict
 option --microsoft --exdict ms-amend.dict --exdict ms-style-guide.dict
+option --macos     --exdict macos.dict
 
 # deprecated. don't use.
 option --ms --microsoft
